# Concepts

This section includes astronomical explanations and quick references for constants available in `pysweph`.

```{toctree}
:maxdepth: 2
migration_guide.md
time_and_zones.md
sidereal_offsets.md
bodies.md
house_systems.md
```
